@@ -1,28 +1,26 @@
 #' Identify closest intervals.
 #'
-#' @param x tbl of intervals
-#' @param y tbl of intervals
+#' @param x [tbl_interval()]
+#' @param y [tbl_interval()]
 #' @param overlap report overlapping intervals
 #' @param suffix colname suffixes in output
 #'
 #' @template groups
 #'
-#' @return \code{data_frame} with additional columns:
-#'   \itemize{
-#'     \item{\code{.dist}}{ distance to closest interval, negative distances denote upstream intervals}
-#'     \item{\code{.overlap}}{ overlap with closest interval}
-#'   }
+#' @return [tbl_interval()] with additional columns:
+#'   - `.dist` distance to closest interval, negative distances denote upstream intervals
+#'   - `.overlap` overlap with closest interval
 #'
-#' @family multi-set-ops
+#' @family multiple set operations
 #' @seealso \url{http://bedtools.readthedocs.io/en/latest/content/tools/closest.html}
 #'
 #' @examples
-#' x <- tibble::tribble(
+#' x <- trbl_interval(
 #'   ~chrom, ~start, ~end,
 #'   'chr1',      100,     125
 #' )
 #'
-#' y <- tibble::tribble(
+#' y <- trbl_interval(
 #'   ~chrom, ~start, ~end,
 #'   'chr1',      25,      50,
 #'   'chr1',     140,     175
@@ -30,18 +28,18 @@
 #'
 #' bed_glyph(bed_closest(x, y))
 #'
-#' x <- tibble::tribble(
-#' ~chrom, ~start, ~end,
-#' "chr1", 500,    600,
-#' "chr2", 5000,   6000
+#' x <- trbl_interval(
+#'   ~chrom, ~start, ~end,
+#'   "chr1", 500,    600,
+#'   "chr2", 5000,   6000
 #' )
 #'
-#' y <- tibble::tribble(
+#' y <- trbl_interval(
 #' ~chrom, ~start, ~end,
-#' "chr1", 100,    200,
-#' "chr1", 150,    200,
-#' "chr1", 550,    580,
-#' "chr2", 7000,   8500
+#'   "chr1", 100,    200,
+#'   "chr1", 150,    200,
+#'   "chr1", 550,    580,
+#'   "chr2", 7000,   8500
 #' )
 #'
 #' bed_closest(x, y)
@@ -49,27 +47,34 @@
 #' bed_closest(x, y, overlap = FALSE)
 #'
 #' # Report distance based on strand
-#' x  <- tibble::tribble(
-#' ~chrom,   ~start,    ~end, ~name, ~score, ~strand,
-#' "chr1",	10,	20,	"a",	1,	"-"
+#' x <- trbl_interval(
+#'   ~chrom, ~start, ~end, ~name, ~score, ~strand,
+#'   "chr1", 10,	   20,   "a",   1,      "-"
 #' )
 #'
-#' y <- tibble::tribble(
-#'  ~chrom,   ~start,    ~end, ~name, ~score, ~strand,
-#'  "chr1",	8,	9,	"b",	1,	"+",
-#'  "chr1",	21,	22,	"b",	1, "-"
+#' y <- trbl_interval(
+#'   ~chrom, ~start, ~end, ~name, ~score, ~strand,
+#'   "chr1", 8,	     9,	   "b",   1,      "+",
+#'   "chr1", 21,	   22,	 "b",   1,      "-"
 #' )
 #'
 #' res <- bed_closest(x, y)
-#' res$.strand_dist <- ifelse(res$strand.x == "+", res$.dist, -(res$.dist))
 #'
-#' #Report absolute distances
+#' # convert distance based on strand
+#' res$.dist_strand <- ifelse(res$strand.x == "+", res$.dist, -(res$.dist))
+#' res
+#'
+#' # report absolute distances
 #' res$.abs_dist <- abs(res$.dist)
+#' res
 #'
 #' @export
 bed_closest <- function(x, y, overlap = TRUE,
                         suffix = c('.x', '.y')){
 
+  if (!is.tbl_interval(x)) x <- tbl_interval(x)
+  if (!is.tbl_interval(y)) y <- tbl_interval(y)
+
   check_suffix(suffix)
 
   x <- arrange(x, chrom, start)
