@@ -1,22 +1,22 @@
 #' Cluster neighboring intervals.
 #'
-#' Output contains an \code{.id} column that can be used in downstream grouping
-#' operations. Default \code{max_dist = 0} means that both overlapping and
+#' Output contains an `.id` column that can be used in downstream grouping
+#' operations. Default `max_dist = 0` means that both overlapping and
 #' book-ended intervals will be clustered.
 #'
-#' @param x tbl of interval
+#' @param x [tbl_interval()]
 #' @param max_dist maximum distance between clustered intervals.
 #'
 #' @template groups
 #'
-#' @return \code{data_frame} with \code{.id} column for clustered intervals.
+#' @return [tbl_interval()] with `.id` column for clustered intervals.
 #'
-#' @family single-set-ops
+#' @family single set operations
 #' @seealso
 #' \url{http://bedtools.readthedocs.org/en/latest/content/tools/cluster.html}
 #'
 #' @examples
-#' x <- tibble::tribble(
+#' x <- trbl_interval(
 #'  ~chrom, ~start, ~end,
 #'  "chr1", 100,  200,
 #'  "chr1", 180,  250,
@@ -29,7 +29,7 @@
 #' bed_cluster(x)
 #'
 #' # glyph illustrating clustering of overlapping and book-ended intervals
-#' x <- tibble::tribble(
+#' x <- trbl_interval(
 #'   ~chrom, ~start, ~end,
 #'   'chr1', 1,      10,
 #'   'chr1', 5,      20,
@@ -43,6 +43,8 @@
 #' @export
 bed_cluster <- function(x, max_dist = 0) {
 
+  if (!is.tbl_interval(x)) x <- tbl_interval(x)
+
   res <- group_by(x, chrom, add = TRUE)
   res <- arrange(res, chrom, start)
 
