@@ -1,3 +1,12 @@
+// merge.cpp
+//
+// Copyright (C) 2016 - 2017 Jay Hesselberth and Kent Riemondy
+//
+// This file is part of valr.
+//
+// This software may be modified and distributed under the terms
+// of the MIT license. See the LICENSE file for details.
+
 #include "valr.h"
 
 //[[Rcpp::export]]
@@ -13,23 +22,20 @@ DataFrame merge_impl(GroupedDataFrame gdf, int max_dist = 0) {
   IntegerVector ids(nr) ;      // store ids
   IntegerVector overlaps(nr) ; // store overlap values
 
-  IntegerVector starts   = df["start"] ;
-  IntegerVector ends     = df["end"] ;
-
-  std::size_t cluster_id = 0; //store counter for cluster id
+  std::size_t cluster_id = 0;  //store counter for cluster id
 
   GroupedDataFrame::group_iterator git = gdf.group_begin() ;
   for (int i = 0; i < ng; i++, ++git) {
 
     SlicingIndex indices = *git ;
 
-    intervalVector intervals = makeIntervalVector(df, indices);
+    ivl_vector_t intervals = makeIntervalVector(df, indices);
 
-    interval_t last_interval = interval_t(0, 0, 0) ;
+    ivl_t last_interval = ivl_t(0, 0, 0) ;
 
     // approach from http://www.geeksforgeeks.org/merging-intervals/
 
-    std::stack<interval_t> s ;
+    std::stack<ivl_t> s ;
     s.push(last_interval) ;
 
     for (auto it : intervals) {
