@@ -1,11 +1,20 @@
+// subtract.cpp
+//
+// Copyright (C) 2016 - 2017 Jay Hesselberth and Kent Riemondy
+//
+// This file is part of valr.
+//
+// This software may be modified and distributed under the terms
+// of the MIT license. See the LICENSE file for details.
+
 #include "valr.h"
 
-void subtract_group(intervalVector vx, intervalVector vy,
+void subtract_group(ivl_vector_t vx, ivl_vector_t vy,
                     std::vector<int>& indices_out,
                     std::vector<int>& starts_out, std::vector<int>& ends_out) {
 
-  intervalTree tree_y(vy) ;
-  intervalVector overlaps ;
+  ivl_tree_t tree_y(vy) ;
+  ivl_vector_t overlaps ;
   IntervalStartSorter<int, int> intervalStartSorter ;
 
   for (auto it : vx) {
@@ -28,9 +37,6 @@ void subtract_group(intervalVector vx, intervalVector vy,
     // sort overlaps by start not sure if necessary
     std::sort(overlaps.begin(), overlaps.end(), intervalStartSorter) ;
 
-    // keep track of the number of new intervals to generate
-    int new_ivl_count = 0;
-
     //iterate through overlaps with current x  interval
     // modifying start and stop as necessary
     for (auto oit : overlaps) {
@@ -38,23 +44,27 @@ void subtract_group(intervalVector vx, intervalVector vy,
       auto y_start = oit.start;
       auto y_stop = oit.stop;
 
-      if (y_start <= x_start) {
-        //advance x_start to end of y
-        x_start = std::min(y_stop, x_stop) ;
-        continue ;
-      } else if (y_start > x_start) {
+      if (x_start > x_stop) {
+        break ;
+      } else if (y_start <= x_start) {
+        // advance x_start to end of y unless y is shorter than x
+        if (x_start > y_stop) {
+          continue ;
+        } else {
+          x_start = y_stop ;
+        };
+      } else {
         // report new interval
         indices_out.push_back(it.value) ;
         starts_out.push_back(x_start) ;
         ends_out.push_back(y_start) ;
         // advance to end of y ivl
         x_start = y_stop;
-        new_ivl_count++ ;
-        continue ;
       }
     }
 
     if (x_start < x_stop) {
+      // report interval
       indices_out.push_back(it.value) ;
       starts_out.push_back(x_start) ;
       ends_out.push_back(x_stop) ;
@@ -63,6 +73,7 @@ void subtract_group(intervalVector vx, intervalVector vy,
     overlaps.clear() ;
   }
 }
+
 //[[Rcpp::export]]
 DataFrame subtract_impl(GroupedDataFrame gdf_x, GroupedDataFrame gdf_y) {
 
@@ -70,58 +81,14 @@ DataFrame subtract_impl(GroupedDataFrame gdf_x, GroupedDataFrame gdf_y) {
   std::vector<int> starts_out ;
   std::vector<int> ends_out ;
 
-  auto ng_x = gdf_x.ngroups() ;
-  auto ng_y = gdf_y.ngroups() ;
-
   DataFrame df_x = gdf_x.data() ;
   DataFrame df_y = gdf_y.data() ;
 
-  // get labels info for grouping
-  DataFrame labels_x(df_x.attr("labels"));
-  DataFrame labels_y(df_y.attr("labels"));
-
-  GroupedDataFrame::group_iterator git_x = gdf_x.group_begin() ;
   // indices_to_report
   std::vector<int> indices_out ;
-  for (int nx = 0; nx < ng_x; nx++, ++git_x) {
 
-    SlicingIndex indices_x = *git_x ;
-
-    // keep track of if x chrom is present in y
-    bool group_seen(false);
-
-    GroupedDataFrame::group_iterator git_y = gdf_y.group_begin() ;
-    for (int ny = 0; ny < ng_y; ny++, ++git_y) {
-
-      SlicingIndex indices_y = *git_y ;
-
-      bool same_groups = compareDataFrameRows(labels_x, labels_y, nx, ny);
-
-      if (same_groups) {
-        group_seen = true ;
-
-        intervalVector vx = makeIntervalVector(df_x, indices_x) ;
-        intervalVector vy = makeIntervalVector(df_y, indices_y) ;
-
-        subtract_group(vx, vy,
-                       indices_out,
-                       starts_out, ends_out) ;
-
-      }
-    }
-
-    // return x intervals if x chromosome not found in y
-    if (group_seen) {
-      continue;
-    } else {
-      intervalVector vx = makeIntervalVector(df_x, indices_x) ;
-      for (auto it : vx) {
-        indices_out.push_back(it.value) ;
-        starts_out.push_back(it.start) ;
-        ends_out.push_back(it.stop) ;
-      }
-    }
-  }
+  // set up interval trees for each chromosome and apply subtract_group
+  GroupApply(gdf_x, gdf_y, subtract_group, std::ref(indices_out), std::ref(starts_out), std::ref(ends_out));
 
   // extract out x data, new intervals will be generated as copies of the parent interval
   DataFrame subset_x = DataFrameSubsetVisitors(df_x, names(df_x)).subset(indices_out, "data.frame");
@@ -140,6 +107,7 @@ DataFrame subtract_impl(GroupedDataFrame gdf_x, GroupedDataFrame gdf_y) {
     names[i] = name_x ;
     out[i] = subset_x[i] ;
   }
+
   out.attr("names") = names ;
   out.attr("class") = classes_not_grouped() ;
   auto nrows = subset_x.nrows() ;
