@@ -6,7 +6,7 @@ test_that('invalid ncol causes an error', {
 })
 
 test_that('BED12 is parsed correctly', {
-  x <- read_bed12(system.file('extdata', 'mm9.bed12.gz', package = 'valr'))
+  x <- read_bed12(valr_example('mm9.bed12.gz'))
   expect_equal(nrow(bed12_to_exons(x)), 29)
   expect_equal(ncol(bed12_to_exons(x)), 6)
 })
