@@ -4,12 +4,12 @@ v <- system.file('extdata', 'test.vcf.gz', package = 'valr')
 x <- read_vcf(v)
 
 test_that('colnames are set in vcf df', {
-   test_that('chrom' %in% colnames(x), TRUE)
-   test_that('start' %in% colnames(x), TRUE)
-   test_that('end' %in% colnames(x), TRUE)
+   expect_true('chrom' %in% colnames(x))
+   expect_true('start' %in% colnames(x))
+   expect_true('end' %in% colnames(x))
 })
 
 test_that('chrom names are set correctly', {
-  test_that(all(stringr::str_detect(x$chrom, '^chr')), TRUE)
+  expect_true(all(stringr::str_detect(x$chrom, '^chr')))
 })
 
