@@ -8,7 +8,7 @@ test_that('intervals can be sorted by size', {
     'chr2', 100,    200,
     'chr1', 400,    700
     )
-  res <- bed_sort(x, by_size = TRUE)
+  expect_warning(res <- bed_sort(x, by_size = TRUE))
   expect_equal(res$start, c(100,200,400,1000))
 })
 
@@ -20,7 +20,7 @@ test_that('intervals can be sorted by size and chrom', {
     'chr2', 100,    200,
     'chr1', 400,    700
     )
-  res <- bed_sort(x, by_size = TRUE, by_chrom = TRUE)
+  expect_warning(res <- bed_sort(x, by_size = TRUE, by_chrom = TRUE))
   expect_equal(res$start, c(100,200,400,1000))
 })
 
@@ -32,7 +32,7 @@ test_that('intervals can be reverse sorted by size', {
     'chr2', 100,    200,
     'chr1', 400,    700
     )
-  res <- bed_sort(x, by_size = TRUE, reverse = TRUE)
+  expect_warning(res <- bed_sort(x, by_size = TRUE, reverse = TRUE))
   expect_equal(res$start, c(1000,400,200,100))
 })
 
@@ -44,7 +44,7 @@ test_that('intervals can be reverse sorted by size and chrom', {
     'chr2', 100,    200,
     'chr1', 400,    700
     )
-  res <- bed_sort(x, by_size = TRUE, by_chrom = TRUE, reverse = TRUE)
+  expect_warning(res <- bed_sort(x, by_size = TRUE, by_chrom = TRUE, reverse = TRUE))
   expect_equal(res$start, c(1000,400,200,100))
 })
 
@@ -56,7 +56,7 @@ test_that('intervals can be sorted by chrom', {
     'chr1', 200,    400,
     'chr3', 400,    700
     )
-  res <- bed_sort(x, by_chrom = TRUE)
+  expect_warning(res <- bed_sort(x, by_chrom = TRUE))
   expect_equal(res$start, c(200,1000,100,400))
 })
 
@@ -68,6 +68,6 @@ test_that('intervals can be reverse sorted by start and chrom', {
     'chr1', 200,    400,
     'chr3', 400,    700
     )
-  res <- bed_sort(x, by_chrom = TRUE, reverse = TRUE)
+  expect_warning(res <- bed_sort(x, by_chrom = TRUE, reverse = TRUE))
   expect_equal(res$start, c(1000,200,100,400)) 
 })
